@@ -8,13 +8,13 @@ Rubric - a notes and bookmarks manager with tagging
 
 =head1 VERSION
 
-version 0.12
+version 0.140
 
- $Id: /my/rjbs/code/rubric/trunk/lib/Rubric.pm 15753 2005-10-26T23:41:53.670331Z rjbs  $
+ $Id: /my/cs/projects/rubric/trunk/lib/Rubric.pm 22357 2006-05-19T03:28:41.586236Z rjbs  $
 
 =cut
 
-our $VERSION = '0.12';
+our $VERSION = '0.140';
 
 =head1 DESCRIPTION
 
@@ -51,6 +51,11 @@ L<http://rjbs.manxome.org/rubric/docs/todo>.
 
 Ricardo SIGNES, C<< <rjbs@cpan.org> >>
 
+=head1 THANKS
+
+...to a lot of people whom I will try to name, in time.  Among these helpful
+people are Ian Langworth, Shawn Sorichetti, John Cappiello, and Dave O'Neill.
+
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-rubric@rt.cpan.org>, or
@@ -58,7 +63,8 @@ through the web interface at L<http://rt.cpan.org>. I will be notified, and
 then you'll automatically be notified of progress on your bug as I make
 changes.
 
-You can also find some support on the #rubric channel on Freenode IRC.
+You can also find some useful people on the #rubric channel on Freenode IRC or
+on the mailing list: L<http://www.listbox.com/subscribe/?listname=rubric>
 
 =head1 SEE ALSO
 
@@ -68,7 +74,7 @@ You can also find some support on the #rubric channel on Freenode IRC.
 
 one of my original inspirations
 
-=item * L<http://pubweb.nwu.edu/~zps869/nv.html>
+=item * L<http://pubweb.northwestern.edu/~zps869/nv.html>
 
 Notational Velocity, another of my inspirations
 
@@ -84,7 +90,7 @@ a social bookmarks system, written in PHP
 
 =head1 COPYRIGHT
 
-Copyright 2004 Ricardo SIGNES.  This program is free software;  you can
+Copyright 2004-2006 Ricardo SIGNES.  This program is free software;  you can
 redistribute it and/or modify it under the same terms as Perl itself.
 
 =cut
