@@ -6,7 +6,7 @@ Rubric::Config - the configuration data for a Rubric
 
 =head1 VERSION
 
- $Id: /my/rjbs/code/rubric/trunk/lib/Rubric/Config.pm 2680 2005-08-20T18:14:28.122231Z rjbs  $
+ $Id: /my/cs/projects/rubric/trunk/lib/Rubric/Config.pm 19187 2006-02-26T20:00:15.946075Z rjbs  $
 
 =head1 DESCRIPTION
 
@@ -27,7 +27,7 @@ use base qw(Class::Accessor);
 use Config::Auto;
 use YAML;
 
-my $config_filename = 'rubric.yml';
+my $config_filename = $ENV{RUBRIC_CONFIG_FILE} || 'rubric.yml';
 
 sub import {
 	my ($class) = shift;
@@ -96,12 +96,31 @@ true if registration new users can't register for accounts via the web
 
 true value if users must have an account to view entries
 
+=item * purge_anonymous_sessions
+
+If true, sessions that are not logged in or login attempts will be deleted at
+teardown.
+
 =item * private_tag
 
 A tag which, if attached to an entry, makes it private.  The default value is
 C<@private>, and I strongly advise against changing it, since I may change the
 way these "system tags" work in the future.
 
+=item * markup_formatter
+
+This entry, if given, should be a mapping of markup names to formatter plugins.
+For example:
+
+  markup_formatter:
+    kwid: Rubric::Entry::Formatter::Kwid
+    tex:  Rubric::Entry::Formatter::TeX
+
+(No.  Neither of those exist.)
+
+If it is not specified in the config file, an entry for C<_default> is set to
+the built-in, extremely simple entry formatter.
+
 =item * one_entry_per_link
 
 if true, each user can have only one entry per link (default: true)
@@ -170,8 +189,10 @@ my $default = {
 	display_localtime   => 0,
 	entries_query_class => 'Rubric::WebApp::Entries',
 	max_page_size       => 100,
+  markup_formatter    => {},
 	one_entry_per_link  => 1,
 	registration_closed => undef,
+  purge_anonymous_sessions  => undef,
 	skip_newuser_verification => undef,
 };
 sub _default { $default }
