@@ -6,7 +6,7 @@ Rubric::User - a Rubric user
 
 =head1 VERSION
 
- $Id: /my/rjbs/code/rubric/trunk/lib/Rubric/User.pm 2680 2005-08-20T18:14:28.122231Z rjbs  $
+ $Id: /my/cs/projects/rubric/trunk/lib/Rubric/User.pm 18681 2006-02-14T03:17:50.649116Z rjbs  $
 
 =head1 DESCRIPTION
 
@@ -101,7 +101,7 @@ sub tags_counted {
 	return $tags;
 }
 
-=head3 related_tags(\@tags)
+=head3 related_tags(\@tags, \%context)
 
 This method returns a reference to an array of tags related to all the given
 tags.  Tags are related if they occur together on entries.  
@@ -109,10 +109,14 @@ tags.  Tags are related if they occur together on entries.
 =cut
 
 sub related_tags {
-	my ($self, $tags) = @_;
+	my ($self, $tags, $context) = @_;
   $tags = [ keys %$tags ] if ref $tags eq 'HASH';
 	return unless $tags and my @tags = @$tags;
 
+  # or an exception?
+  return [] if  (grep { $_ eq '@private' } @$tags)
+         and (($context->{user}||'') ne $self->username);
+
 	my $query = q|
 	SELECT DISTINCT tag FROM entrytags
 	WHERE entry IN (SELECT id FROM entries WHERE user = ?)
@@ -127,7 +131,7 @@ sub related_tags {
 	$self->db_Main->selectcol_arrayref($query, undef, $self->username);
 }
 
-=head3 related_tags_counted(\@tags)
+=head3 related_tags_counted(\@tags, \%context)
 
 This is the obvious conjunction of C<related_tags> and C<tags_counted>.  It
 returns an arrayref of arrayrefs, each a pair of tag/occurance values.
@@ -135,11 +139,15 @@ returns an arrayref of arrayrefs, each a pair of tag/occurance values.
 =cut
 
 sub related_tags_counted {
-	my ($self, $tags) = @_;
+	my ($self, $tags, $context) = @_;
   return unless $tags;
   $tags = [ keys %$tags ] if ref $tags eq 'HASH';
 	return unless my @tags = @$tags;
 
+  # or an exception?
+  return [] if  (grep { $_ eq '@private' } @$tags)
+         and (($context->{user}||'') ne $self->username);
+
 	my $query = q|
 		SELECT DISTINCT tag, COUNT(*) AS count
 		FROM entrytags
