@@ -6,13 +6,13 @@ Rubric::WebApp - the web interface to Rubric
 
 =head1 VERSION
 
-version 0.12
+version 0.140
 
- $Id: /my/rjbs/code/rubric/trunk/lib/Rubric/WebApp.pm 15753 2005-10-26T23:41:53.670331Z rjbs  $
+ $Id: /my/cs/projects/rubric/trunk/lib/Rubric/WebApp.pm 22357 2006-05-19T03:28:41.586236Z rjbs  $
 
 =cut
 
-our $VERSION = '0.12';
+our $VERSION = '0.140';
 
 =head1 SYNOPSIS
 
@@ -106,9 +106,8 @@ sub redirect_root {
 
 =head2 cgiapp_init
 
-This method is called during CGI::Application's initialization.  It finds (or
-creates) a CGI::Session, checks for a login, checks for updates to result-set
-paging, and starts processing the request path. 
+This method is called during CGI::Application's initialization.  It sets up the
+session configuration.
 
 =cut
 
@@ -123,11 +122,23 @@ sub cgiapp_init {
       -name    => 'rubric_session'
     }
   );
-  
+
   my $login_class = Rubric::Config->login_class;
   eval "require $login_class";
   $login_class->check_for_login($self);
+}
 
+=head2 cgiapp_prerun
+
+This method is called before the selected runmode.  It checks for a login,
+checks for updates to result-set paging, and starts processing the request
+path. 
+
+=cut
+
+sub cgiapp_prerun {
+  my ($self) = @_;
+  
   $self->check_pager_data;
 
   my @path = split '/', $self->query->path_info;
@@ -195,7 +206,7 @@ sub template {
   $stash->{page} = $self->param('page');
 
   my $type = $self->query->param('format');
-     $type = 'html' unless $type and $type =~ /^\w+$/;
+     $type = 'html' unless $type and $type =~ /^[\pL\d_]+$/;
 
   my ($content_type, $output) =
     Rubric::Renderer->process($template, $type, $stash);
@@ -240,7 +251,13 @@ sub _default_handler {
 sub _entries_shortcut {
   my ($self, $user) = @_;
   my $path = $self->param('path');
-  unshift @$path, 'user', $user, 'tags';
+
+  # If there the number of elements in the path is odd, the first one is tags;
+  # otherwise, it's a normal query; this may or may not be safe, in the end.  I
+  # guess we'll find out. -- rjbs, 2006-02-20
+  unshift @$path, 'tags' if @$path % 2;
+  unshift @$path, 'user', $user;
+
   $self->entries;
 }
 
@@ -254,8 +271,11 @@ users.
 sub teardown {
   my ($self) = @_;
 
-  $self->session->delete unless $self->param('current_user')
-                             or $self->get_current_runmode eq 'login';
+  if (Rubric::Config->purge_anonymous_sessions) {
+    $self->session->delete unless $self->param('current_user')
+                               or $self->get_current_runmode eq 'login'
+                               or $self->get_current_runmode eq 'post';
+  }
 }
 
 =head2 entries
@@ -292,7 +312,8 @@ sub entry {
          or  $entry->user ne $self->param('current_user'));
 
   $self->template('entry_long' => {
-    entry => $self->param('entry'),
+    entry     => $self->param('entry'),
+    self_url  => $self->query->self_url(),
     long_form => 1
   });
 }
@@ -383,7 +404,7 @@ object, then redirects the user to the root of the Rubric site.
 
 sub logout {
   my ($self) = @_;
-  $self->session->param('current_user', undef);
+  $self->session->clear('current_user');
   $self->param('current_user', undef);
 
   return $self->redirect_root("Logged out...");
@@ -508,7 +529,6 @@ sub validate_prefs {
   };
   
   my $results = Data::FormValidator->check($prefs, $profile);
-
 }
 
 =end future
@@ -590,7 +610,7 @@ sub validate_newuser_form {
   my ($self, $newuser) = @_;
   my %errors;
 
-  if ($newuser->{username} and $newuser->{username} !~ /^[\w\d.]+$/) {
+  if ($newuser->{username} and $newuser->{username} !~ /^[\pL\d_.]+$/) {
     undef $newuser->{username};
     $errors{username_invalid} = 1;
   } elsif (Rubric::User->retrieve($newuser->{username})) {
@@ -988,7 +1008,10 @@ sub doc {
   my ($self) = @_;
 
   $self->get_doc;
-  $self->template("docs/" . $self->param('doc_page'));
+  my $output = eval { $self->template("docs/" . $self->param('doc_page')); };
+
+  # XXX: this should instead redirect to a 404-page
+  return $output ? $output : $self->redirect_root("no such document");
 }
 
 =head2 get_doc
@@ -1001,8 +1024,8 @@ sub get_doc {
   my ($self) = @_;
 
   my $doc_page = $self->next_path_part;
-  return $doc_page =~ /^\w+$/ ? $self->param(doc_page => $doc_page)
-                              : ();
+  return $doc_page =~ /^[\pL\d_]+$/ ? $self->param(doc_page => $doc_page)
+                                    : ();
 }
 
 =head1 TODO
