@@ -10,7 +10,7 @@ Rubric::WebApp::Login - web login processing
 
 version 0.01
 
- $Id: /my/rjbs/code/rubric/trunk/lib/Rubric/WebApp/Login.pm 2680 2005-08-20T18:14:28.122231Z rjbs  $
+ $Id: /my/cs/projects/rubric/trunk/lib/Rubric/WebApp/Login.pm 18706 2006-02-16T04:37:20.091139Z rjbs  $
 
 =cut
 
@@ -91,7 +91,7 @@ is a valid username.
 
 sub valid_username {
 	my ($self, $username) = @_;
-	$username =~ /^\w+$/;
+	$username =~ /^[\pL\d_]+$/;
 }
 
 =head2 get_login_user($username)
